SDUIPhotoView class

Descriptor of a PhotoView

JSON Attributes

  • url: URL of the image
Inheritance

Constructors

SDUIPhotoView()

Properties

action ↔ SDUIAction
getter/setter pairinherited
children ↔ List<SDUIWidget>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
getter/setter pair

Methods

attachPageController(PageController? controller) → void
inherited
attachScreen(SDUIWidget screen) → void
inherited
child() → SDUIWidget?
Return the first child
inherited
childrenWidgets(BuildContext context) → List<Widget>
Return the list of children Widget
inherited
fromJson(Map<String, dynamic>? json) → SDUIWidget
Load the attributes of the widget descriptor from
override
hasChildren() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAlignment(String? alignment) → Alignment?
inherited
toAxis(String? direction) → Axis
inherited
toBoxFit(String? fit) → BoxFit?
inherited
toClip(String? clip) → Clip?
inherited
toColor(String? hexColor) → Color?
inherited
toCrossAxisAlignment(String? value) → CrossAxisAlignment
inherited
toIcon(String? code, {double? size, String? color}) → Widget?
inherited
toIconData(String? code) → IconData?
inherited
toMainAxisAlignment(String? value) → MainAxisAlignment
inherited
toMainAxisSize(String? value) → MainAxisSize
inherited
toString() → String
A string representation of this object.
inherited
toTextAlign(String? alignment) → TextAlign?
inherited
toWidget(BuildContext context) → Widget
Return the associated Widget
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited